#! /usr/bin/perl
#
# wanha - your pesky URL-guardian for IRC
# Copyright (C) 2006 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


use strict;
use warnings FATAL => 'all';
use diagnostics;

require "http.pl";
require "html.pl";
require "db.pl";
require "dbops.pl";
require "session.pl";
require "url.pl";
require "urllist.pl";
require "common.pl";


# 0: latest url id
# 1: count
# ...: ignored chans
# r: (url_id, url_date, chan_id, chan_name, nick_id, nick_name, url_url)
sub get_latest($$@)
{
	my ($latest_id, $count, $ignore);
	my ($query, $result);
	my @ret;

	$latest_id = $_[0];
	$count = $_[1];
	shift @_; shift @_;

	$ignore = "";
	if ($#_ >= 0) {
		foreach my $id (@_) {
			$ignore .= " AND urls.chan != $_[0]";
		}
		$ignore =~ s/ AND (.*)/AND ($1) /;
	}

	$count = &Common::min($count, 100);

	$query = "SELECT urls.id, urls.url, " .
				&DBOps::get_date_fmt("urls.time") . ", " .
				"chans.id, chans.chan, " .
				"nicks.id, nicks.nick " .
			"FROM urls, chans, nicks " .
			"WHERE urls.id > $latest_id $ignore " .
				"AND urls.nick = nicks.id " .
				"AND urls.chan = chans.id " .
			"ORDER BY urls.id ASC " .
			"LIMIT $count";
	$result = &DB::query($query);
	($result->ntuples == 0) && return ();

	while (my ($url_id, $url_url, $url_date, $chan_id, $chan_name,
				$nick_id, $nick_name) = $result->fetchrow) {
		$chan_name =~ s/,/./g;
		$nick_name =~ s/,/./g;
		push(@ret, "$url_id,$url_date,$chan_id,$chan_name," .
				"$nick_id,$nick_name,$url_url");
	}
	return @ret;
}


# 0: sid
sub latest($)
{
	my ($sid) = @_;

	my ($latest, $age, $count, $date, $reset) =
			&Session::get_cookie_info($sid);
	my @ignore = &Session::get_ignore_chans($sid);
	my @urls = &get_latest($latest, $count, @ignore);

	if ($reset == 1) {
		&Session::set_latest($sid, &Session::get_latest_url_id());
		print <<EOF;
<p>L10N to be done. Latest URLs reset each time the page is loaded.
UI for some of the functionality is still missing.</p>
EOF
	}

	if ($#urls == -1) {
		printf "<h1>%s</h1>\n", &Lang::get("latest-no-new-urls");
		return;
	}

	my @print;
	foreach (@urls) {
		my ($url_id, $url_date, $chan_id, $chan_name, $nick_id,
				$nick_name, $url_url) = split(/,/, $_, 7);
		push(@print, "$url_id,$url_date,0,$chan_id,$chan_name," .
				"$url_url");
	}
	printf "<h1>%s</h1>\n", &Lang::get("latest-label");
	&URLList::print(2, 1, @print);

	if ($reset == 0) {
		printf "<p><a href=\"%s\">%s</a></p>\n",
				&URL::latest(1),
				&Lang::get("latest-reset");
	}
}


sub main()
{
	my $sid;
	my $phase;

	$sid = &Session::get_session();
	if (! defined($sid)) {
		&HTTP::redirect(&URL::session(1, "latest"));
		&HTTP::print_header();
		exit(0);
	}

	if (&HTTP::get("reset", 0) == 1) {
		&Session::set_latest($sid, &Session::get_latest_url_id());
		&HTTP::redirect(&URL::latest());
		&HTTP::print_header();
		exit(0);
	}

	&HTTP::print_header();
	&HTML::print_header();

	&latest($sid);

	&HTML::print_footer();
}


&main();
