#! /usr/bin/perl
#
# wanha - your pesky URL-guardian for IRC
# Copyright (C) 2006 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


use strict;
use warnings FATAL => 'all';
use diagnostics;

require "http.pl";
require "html.pl";
require "session.pl";
require "db.pl";
require "url.pl";


sub error($)
{
	my ($error) = @_;
	&HTTP::print_header();
	&HTML::print_header();
	printf "<h1>%s</h1>\n", &Lang::get("txt-title-error");
	printf "<p>%s</p>\n", &Lang::get($error);
	&HTML::print_footer();

}


# 0: sid
# 1: phase
# 2: go
sub try_set_session($$$)
{
	my ($sid, $phase, $go) = @_;

	if ($phase == 1) {
		if (! defined($sid)) {
			$sid = &Session::create_sid();
			if (! defined($sid)) {
				&error("cant-create-session");
				exit(0);
			}
		}
		&HTTP::set_cookie("sid", $sid, 30 * 24 * 60 * 60);
		&HTTP::redirect(&URL::session(2, $go));
		&HTTP::print_header();
		exit(0);
	}

	if ($phase == 2) {
		if (! defined($sid)) {
			&error("cant-set-session");
			exit(0);
		}
	}
}


sub main()
{
	my $sid = &Session::get_session();
	my $phase = &HTTP::get("set");
	my $go = &HTTP::get("go");

	if (defined($phase) || (! defined($sid) && ! defined($phase))) {
		$phase = 1 if (! defined($phase));
		&try_set_session($sid, $phase, $go);
	}

	# Cookie set

	if (defined($go)) {
		if ($go eq "latest") {
			&HTTP::redirect(&URL::latest());
		}
	}

	&HTTP::print_header();
	&HTML::print_header();

	print "<tt>sid = $sid</tt><br />\n";

	&HTML::print_footer();
}


&main();
